# Where is the Documentation?

To view the documentation open: [_build/html/index.html](./_build/html/index.html)

## Building the Docs

Before building the docs, make sure to install the following with either pip:

    pip install sphinx sphinx_rtd_theme

Or with Anaconda:

    conda install sphinx sphinx_rtd_theme

To build the documentation run the following from this folder:

    make clean && make html
